containertools.move_parentage_children_and_spanners_from_components_to_empty_container
======================================================================================

.. autofunction:: abjad.tools.containertools.move_parentage_children_and_spanners_from_components_to_empty_container.move_parentage_children_and_spanners_from_components_to_empty_container
